==> improvements-2.0.1.tar.gz: improvements/src/ImprovementsEventSubscriber.php <==
<?php

namespace Drupal\improvements;

use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Event Subscriber MyEventSubscriber.
 */
class ImprovementsEventSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[KernelEvents::VIEW][] = ['onKernelView', 10];
    $events[KernelEvents::RESPONSE][] = ['onKernelResponse', 10];
    return $events;
  }

  /**
   * KernelEvents::VIEW event callback.
   *
   * @param \Symfony\Component\HttpKernel\Event\GetResponseForControllerResultEvent|\Symfony\Component\HttpKernel\Event\ViewEvent $event
   * @todo Remove \Symfony\Component\HttpKernel\Event\GetResponseForControllerResultEvent after Drupal 8 support end
   */
  public function onKernelView($event) {
    // Create hook_page_ROUTE_NAME_result_alter()
    $result = $event->getControllerResult();
    $current_route_name = \Drupal::routeMatch()->getRouteName();
    \Drupal::moduleHandler()->alter('page_' . str_replace('.', '_', $current_route_name) . '_result', $result);
    $event->setControllerResult($result);
  }

  /**
   * KernelEvents::RESPONSE event callback.
   *
   * @param \Symfony\Component\HttpKernel\Event\FilterResponseEvent|\Symfony\Component\HttpKernel\Event\ResponseEvent $event
   * @todo Remove \Symfony\Component\HttpKernel\Event\FilterResponseEvent after Drupal 8 support end
   */
  public function onKernelResponse($event) {
    // Remove toolbar/toolbar library from page attachments
    $response = $event->getResponse();
    if (method_exists($response, 'getAttachments')) {
      $attachments = $response->getAttachments();
      if (isset($attachments['library'])) {
        $attachments['library'] = array_diff($attachments['library'], ['toolbar/toolbar']);
        $response->setAttachments($attachments);
      }
    }
  }

}

==> improvements-2.0.3.tar.gz: improvements/src/ImprovementsEventSubscriber.php <==
<?php

namespace Drupal\improvements;

use Drupal\Core\EventSubscriber\MainContentViewSubscriber;
use Drupal\Core\Routing\RouteObjectInterface;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Event Subscriber MyEventSubscriber.
 */
class ImprovementsEventSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events[KernelEvents::VIEW][] = ['onKernelView', 10];
    $events[KernelEvents::RESPONSE][] = ['onKernelResponse', 10];
    return $events;
  }

  /**
   * KernelEvents::VIEW event callback.
   *
   * @param \Symfony\Component\HttpKernel\Event\GetResponseForControllerResultEvent|\Symfony\Component\HttpKernel\Event\ViewEvent $event
   * @todo Remove \Symfony\Component\HttpKernel\Event\GetResponseForControllerResultEvent after Drupal 8 support end
   */
  public function onKernelView($event): void {
    // Create hook_page_ROUTE_NAME_result_alter()
    $result = $event->getControllerResult();
    $current_route_name = \Drupal::routeMatch()->getRouteName();
    \Drupal::moduleHandler()->alter('page_' . str_replace('.', '_', $current_route_name) . '_result', $result);

    // Remove #title for modal content
    /** @see \Drupal\Core\Render\MainContent\ModalRenderer::renderResponse() */
    if (
      $event->getRequest()->query->get(MainContentViewSubscriber::WRAPPER_FORMAT) == 'drupal_modal' &&
      isset($result['#pre_render'])
    ) {
      foreach ($result['#pre_render'] as $key => $function) {
        if (is_array($function) && isset($function[1]) && $function[1] == 'buildTitle') {
          unset($result['#pre_render'][$key]);
        }
      }
    }

    $event->setControllerResult($result);
  }

  /**
   * KernelEvents::RESPONSE event callback.
   *
   * @param \Symfony\Component\HttpKernel\Event\FilterResponseEvent|\Symfony\Component\HttpKernel\Event\ResponseEvent $event
   * @todo Remove \Symfony\Component\HttpKernel\Event\FilterResponseEvent after Drupal 8 support end
   */
  public function onKernelResponse($event): void {
    // Remove toolbar/toolbar library from page attachments
    $response = $event->getResponse();
    if (method_exists($response, 'getAttachments')) {
      $attachments = $response->getAttachments();
      if (isset($attachments['library'])) {
        $attachments['library'] = array_diff($attachments['library'], ['toolbar/toolbar']);
        $response->setAttachments($attachments);
      }
    }

    // Clear page cache on clear render cache
    $request = $event->getRequest();
    $route_name = $request->attributes->get(RouteObjectInterface::ROUTE_NAME);
    if ($route_name == 'admin_toolbar_tools.flush_rendercache') {
      $database = \Drupal::database();
      if ($database->schema()->tableExists('cache_page')) {
        $database->truncate('cache_page')->execute();
      }
    }
  }

}
